@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1313 2015-02-04 13:16:02Z willem $
+# $Id: SEC.pm 1315 2015-02-06 10:01:15Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '0.21_10';
-$SVNVERSION = (qw$LastChangedRevision: 1313 $)[1];
+$VERSION    = '0.21_11';
+$SVNVERSION = (qw$LastChangedRevision: 1315 $)[1];
 
 
 =head1 NAME
@@ -44,11 +44,11 @@ use integer;
 use warnings;
 use Carp;
 
-require Net::DNS::RR::DS;
-require Net::DNS::RR::CDS;
-require Net::DNS::RR::DLV;
-require Net::DNS::RR::RRSIG;
-require Net::DNS::RR::SIG;
+eval{ require Net::DNS::RR::CDS };
+eval{ require Net::DNS::RR::DLV };
+eval{ require Net::DNS::RR::DS };
+eval{ require Net::DNS::RR::RRSIG };
+eval{ require Net::DNS::RR::SIG };
 
 
 =head1 UTILITY FUNCTIONS
@@ -131,20 +131,20 @@ All Rights Reserved
 =head1 LICENSE
 
 Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
-provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
-supporting documentation, and that the name of the author not be used
-in advertising or publicity pertaining to distribution of the software
-without specific prior written permission.
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
 
-THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
-INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO
-EVENT SHALL AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
-DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
-PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
-THIS SOFTWARE.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
