@@ -1,10 +1,10 @@
 package Net::DNS::SEC::DSA;
 
 #
-# $Id: DSA.pm 1306 2015-01-29 09:13:36Z willem $
+# $Id: DSA.pm 1314 2015-02-06 09:59:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1306 $)[1];
+$VERSION = (qw$LastChangedRevision: 1314 $)[1];
 
 
 =head1 NAME
@@ -46,7 +46,7 @@ use strict;
 use integer;
 use warnings;
 use Carp;
-use Crypt::OpenSSL::DSA;
+use Crypt::OpenSSL::DSA 0.10;
 use Digest::SHA;
 use MIME::Base64;
 
@@ -130,8 +130,24 @@ Copyright (c)2014 Dick Franks.
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
